#include "SmartDisplay.hpp"
#include "SmartTime.hpp"

SmartDisplay::SmartDisplay(Adafruit_SSD1306 *display)
{
    m_display = display;
}

void SmartDisplay::printTeaConfigScreen(TeaData tea)
{

    resetDisplay();

    m_display->println(tea.m_teaName);
    m_display->print(tea.m_waterTemp);
    m_display->drawCircle(m_display->getCursorX() + 4, m_display->getCursorY(), 1, WHITE);
    m_display->println(" C");

    m_display->setTextSize(2);
    String steepingTime = SmartTime::formatSeconds(tea.m_steepingSeconds);
    m_display->print(steepingTime);
    m_display->setTextSize(1);
    m_display->setCursor(m_display->getCursorX(), m_display->getCursorY() + 7);
    m_display->println(" min");

    m_display->display();
}

void SmartDisplay::printTeaSteepingProgressScreen(TeaData tea, int remainingSeconds)
{
    resetDisplay();

    m_display->println(tea.m_teaName);
    m_display->println(" (Steeping)");

    m_display->setTextSize(2);
    String remainingTime = SmartTime::formatSeconds(remainingSeconds);
    m_display->print(remainingTime);
    m_display->setTextSize(1);
    m_display->setCursor(m_display->getCursorX(), m_display->getCursorY() + 7);
    m_display->println(" min");

    m_display->display();
}

void SmartDisplay::printWaitForRFIDScreen()
{
    resetDisplay();
    m_display->println("Waiting for RFID scan...");

    m_display->display();
}

void SmartDisplay::printRequestFeedbackScreen(TeaData tea)
{
    resetDisplay();

    m_display->println("Feedback on brew intensity");
    m_display->println();
    m_display->println("|less| perfect |more|");

    m_display->display();
}

void SmartDisplay::printAddNewTeaConfigScreen(TeaData tea)
{
    resetDisplay();

    m_display->println("Add initial config for new tea");
    m_display->println();
    m_display->print("Steeping time:");
    String steepingTime = SmartTime::formatSeconds(tea.m_steepingSeconds);
    m_display->print(steepingTime);
    m_display->setTextSize(1);
    m_display->println(" min");

    m_display->display();
}

void SmartDisplay::printMsg(const String &s)
{
    resetDisplay();
    m_display->setCursor(0, 10);
    m_display->println(s);
    m_display->display();
}
void SmartDisplay::printMsg(unsigned long l)
{
    resetDisplay();
    m_display->setCursor(0, 10);
    m_display->println(l);
    m_display->display();
}

void SmartDisplay::resetDisplay()
{
    m_display->clearDisplay();
    m_display->setTextColor(WHITE);
    m_display->setTextSize(1);
    m_display->setCursor(0, 0);
}