#include "SmartSound.hpp"
#include "nevergonna.h"

SmartSound::SmartSound(int buzzerPin)
{
    m_buzzerPin = buzzerPin;
}

void SmartSound::play(Sound sound, int tempo)
{
    switch (sound)
    {
    case NeverGonna:
        playSound(nevergonna, nevergonna_notes, tempo);
        break;
    case Bing:
        break;
    }
}

void SmartSound::playSound(int melody[], int notes, int tempo)
{

    // this calculates the duration of a whole note in ms
    int wholenote = (60000 * 4) / tempo;
    int divider = 0, noteDuration = 0;

    // iterate over the notes of the melody.
    // Remember, the array is twice the number of notes (notes + durations)
    for (int thisNote = 0; thisNote < notes * 2; thisNote = thisNote + 2)
    {

        // calculates the duration of each note
        divider = melody[thisNote + 1];
        if (divider > 0)
        {
            // regular note, just proceed
            noteDuration = (wholenote) / divider;
        }
        else if (divider < 0)
        {
            // dotted notes are represented with negative durations!!
            noteDuration = (wholenote) / abs(divider);
            noteDuration *= 1.5; // increases the duration in half for dotted notes
        }

        // we only play the note for 90% of the duration, leaving 10% as a pause
        tone(m_buzzerPin, melody[thisNote], noteDuration * 0.9);
        // Wait for the specief duration before playing the next note.
        delay(noteDuration);
        // stop the waveform generation before the next note.
        noTone(m_buzzerPin);
    }
}